@@ -301,6 +301,7 @@ void init_object(py::module_ &m)
     py::bind_vector<ObjectList>(m, "_ObjectList") // Autoformat fix
         .def("__repr__", [](ObjectList &ol) {
             std::ostringstream ss;
+            ss.imbue(std::locale::classic());
             bool first = true;
             ss << "pikepdf._core._ObjectList([";
             for (auto &h : ol) {
@@ -671,7 +672,8 @@ void init_object(py::module_ &m)
                     return h.getOperatorValue();
                 else if (h.isString())
                     return h.getUTF8Value();
-                throw py::notimpl_error("don't know how to __str__ this object");
+                // Python's default __str__ calls __repr__
+                return objecthandle_repr(h);
             })
         .def("__bytes__",
             [](QPDFObjectHandle &h) {
@@ -859,7 +861,7 @@ void init_object(py::module_ &m)
             Convert to a QPDF JSON representation of the object.
 
             See the QPDF manual for a description of its JSON representation.
-            http://qpdf.sourceforge.net/files/qpdf-manual.html#ref.json
+            https://qpdf.readthedocs.io/en/stable/json.html#qpdf-json-format
 
             Not necessarily compatible with other PDF-JSON representations that
             exist in the wild.
@@ -875,7 +877,7 @@ void init_object(py::module_ &m)
               representable and will be serialized as ``null``.
 
             Args:
-                dereference (bool): If True, dereference the object is this is an
+                dereference (bool): If True, dereference the object if this is an
                     indirect object.
                 schema_version (int): The version of the JSON schema. Defaults to 2.
 
